@@ -1,12 +1,10 @@
 package App::Info::RDBMS;
 
-# $Id: RDBMS.pm 7356 2004-11-08 17:51:29Z theory $
-
 use strict;
 use App::Info;
 use vars qw(@ISA $VERSION);
 @ISA = qw(App::Info);
-$VERSION = '0.27';
+$VERSION = '0.57';
 
 1;
 __END__
@@ -28,14 +26,19 @@ implementation.
 Currently, App::Info::RDBMS adds no more methods than those from its parent
 class, App::Info.
 
-=head1 BUGS
+=head1 SUPPORT
 
-Report all bugs via the CPAN Request Tracker at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Info>.
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/app-info/>. Feel free to fork and
+contribute!
+
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/app-info/issues/> or by sending mail to
+L<bug-App-Info@rt.cpan.org|mailto:bug-App-Info@rt.cpan.org>.
 
 =head1 AUTHOR
 
-David Wheeler <L<david@wheeler.net|"david@wheeler.net">>
+David E. Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
@@ -44,7 +47,7 @@ L<App::Info::RDBMS::PostgreSQL|App::Info::RDBMS::PostgreSQL>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2004, David Wheeler. All Rights Reserved.
+Copyright (c) 2002-2011, David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
